@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library (in the file LGPL.txt); if not, 
- * write to the Free Software Foundation, Inc., 51 Franklin St, 
- * Fifth Floor, Boston, MA  02110-1301  USA
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -24,10 +23,10 @@
  */
 
 #ifndef _SVNCPP_CONTEXT_LISTENER_HPP_
-#define _SVNCPP_CONTEXT_LISTENER_HPP_ 
+#define _SVNCPP_CONTEXT_LISTENER_HPP_
 
 // stl
-#include <string>
+#include "svncpp/string_wrapper.hpp"
 
 // Subversion api
 #include "svn_client.h"
@@ -50,7 +49,7 @@ namespace svn
      * this method will be called to retrieve
      * authentication information
      *
-     * WORKAROUND FOR apr_xlate PROBLEM: 
+     * WORKAROUND FOR apr_xlate PROBLEM:
      * STRINGS ALREADY HAVE TO BE UTF8!!!
      *
      * @param username
@@ -60,13 +59,13 @@ namespace svn
      * @return continue action?
      * @retval true continue
      */
-    virtual bool 
-    contextGetLogin (const std::string & realm,
-                     std::string & username, 
-                     std::string & password,
-                     bool & maySave) = 0;
+    virtual bool
+    contextGetLogin(const std::string & realm,
+                    std::string & username,
+                    std::string & password,
+                    bool & maySave) = 0;
 
-    /** 
+    /**
      * this method will be called to notify about
      * the progress of an ongoing action
      *
@@ -79,13 +78,13 @@ namespace svn
      * @param revision
      */
     virtual void
-    contextNotify (const char *path,
-                   svn_wc_notify_action_t action,
-                   svn_node_kind_t kind,
-                   const char *mime_type,
-                   svn_wc_notify_state_t content_state,
-                   svn_wc_notify_state_t prop_state,
-                   svn_revnum_t revision) = 0;
+    contextNotify(const char *path,
+                  svn_wc_notify_action_t action,
+                  svn_node_kind_t kind,
+                  const char *mime_type,
+                  svn_wc_notify_state_t content_state,
+                  svn_wc_notify_state_t prop_state,
+                  svn_revnum_t revision) = 0;
 
     /*
      * this method will be called periodically to allow
@@ -101,7 +100,7 @@ namespace svn
      * this method will be called to retrieve
      * a log message
      *
-     * WORKAROUND FOR apr_xlate PROBLEM: 
+     * WORKAROUND FOR apr_xlate PROBLEM:
      * STRINGS ALREADY HAVE TO BE UTF8!!!
      *
      * @param msg log message
@@ -109,7 +108,7 @@ namespace svn
      * @retval true continue
      */
     virtual bool
-    contextGetLogMessage (std::string & msg) = 0;
+    contextGetLogMessage(std::string & msg) = 0;
 
     typedef enum
     {
@@ -125,7 +124,7 @@ namespace svn
      */
     struct SslServerTrustData
     {
-    public:
+public:
       /** bit coded failures */
       apr_uint32_t failures;
 
@@ -138,15 +137,15 @@ namespace svn
       std::string realm;
       bool maySave;
 
-      SslServerTrustData (const apr_uint32_t failures_ = 0)
-        : failures (failures_), hostname (""), fingerprint (""),
-          validFrom (""), validUntil (""), issuerDName (""),
-          realm (""), maySave (true)
+      SslServerTrustData(const apr_uint32_t failures_ = 0)
+          : failures(failures_), hostname(""), fingerprint(""),
+          validFrom(""), validUntil(""), issuerDName(""),
+          realm(""), maySave(true)
       {
       }
 
-      SslServerTrustData (const SslServerTrustData & src)
-        : failures (src.failures)
+      SslServerTrustData(const SslServerTrustData & src)
+          : failures(src.failures)
       {
         hostname = src.hostname;
         fingerprint = src.fingerprint;
@@ -173,7 +172,7 @@ namespace svn
         failures = src.failures;
 
         return *this;
-      }        
+      }
     };
 
 
@@ -181,20 +180,20 @@ namespace svn
      * this method is called if there is ssl server
      * information, that has to be confirmed by the user
      *
-     * @param data 
+     * @param data
      * @param acceptedFailures
      * @return @a SslServerTrustAnswer
      */
     virtual SslServerTrustAnswer
-    contextSslServerTrustPrompt (const SslServerTrustData & data, 
-                                 apr_uint32_t & acceptedFailures) = 0;
+    contextSslServerTrustPrompt(const SslServerTrustData & data,
+                                apr_uint32_t & acceptedFailures) = 0;
 
     /**
      * this method is called to retrieve client side
      * information
      */
-    virtual bool 
-    contextSslClientCertPrompt (std::string & certFile) = 0;
+    virtual bool
+    contextSslClientCertPrompt(std::string & certFile) = 0;
 
     /**
      * this method is called to retrieve the password
@@ -205,11 +204,11 @@ namespace svn
      * @param maySave
      */
     virtual bool
-    contextSslClientCertPwPrompt (std::string & password, 
-                                  const std::string & realm, 
-                                  bool & maySave) = 0;
+    contextSslClientCertPwPrompt(std::string & password,
+                                 const std::string & realm,
+                                 bool & maySave) = 0;
 
-    virtual ~ContextListener () { }
+    virtual ~ContextListener() { }
   };
 }
 
