@@ -43,9 +43,18 @@ AboutDlg::AboutDlg(wxWindow * parent, const wxLocale & locale)
   SetTitle(title);
 
   // format string
-  const wxString version(wxString::Format(
-                           _("%s Version %s"),
-                           APPLICATION_NAME, Utf8ToLocal(RAPIDSVN_VER_STR).c_str()));
+  wxString version;
+  
+  if (0 == RAPIDSVN_VER_REVISION)
+  {
+    version = wxString::Format(_("%s Version %s"),
+                               APPLICATION_NAME, Utf8ToLocal(RAPIDSVN_VER_STR).c_str());
+  }
+  else
+  {
+    version = wxString::Format(_("%s Version %s Revision %d"),
+                               APPLICATION_NAME, Utf8ToLocal(RAPIDSVN_VER_STR).c_str(), RAPIDSVN_VER_REVISION);
+  }
 
   // TODO: Make these two constants in version.hpp translatable and wxT()'ed respectively.
   // Until then use the kludge of pretending they're UTF8 to save some silly looking ifdef's
@@ -82,11 +91,14 @@ Language: %s\n\
 System Name: %s\n\
 Canonical Name: %s\n"));
 
+  const svn_version_t * pSvnVersion = svn_subr_version();
+  assert(pSvnVersion != 0);
+
   const wxString built(wxString::Format(
                          builtFmt,
                          wxMAJOR_VERSION, wxMINOR_VERSION,
                          wxRELEASE_NUMBER, unicode.c_str(),
-                         SVN_VER_MAJOR, SVN_VER_MINOR, SVN_VER_MICRO));
+                         pSvnVersion->major, pSvnVersion->minor, pSvnVersion->patch));
 
   const wxString info(wxString::Format(
                         infoFmt,
