@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program (in the file GPL.txt); if not, write to 
- * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -31,35 +30,29 @@
 // svncpp
 #include "svncpp/context_listener.hpp"
 
-// forward declarations
-namespace svn
-{
-  struct ContextListener::SslServerTrustData;
-};
-
 class CertDlg : public wxDialog
 {
 public:
-  CertDlg (wxWindow * parent,
-    const svn::ContextListener::SslServerTrustData & data);
+  CertDlg(wxWindow * parent,
+          const svn::ContextListener::SslServerTrustData & data);
 
-  virtual ~CertDlg ();
+  virtual ~CertDlg();
 
   svn::ContextListener::SslServerTrustAnswer
-  Answer () const;
+  Answer() const;
 
   wxUint32
-  AcceptedFailures () const;
+  AcceptedFailures() const;
 
 private:
   struct Data;
   Data * m;
 
 private:
-  DECLARE_EVENT_TABLE ()
+  DECLARE_EVENT_TABLE()
 
-  void OnPerm (wxCommandEvent & event);
-  void OnTemp (wxCommandEvent & event);
+  void OnPerm(wxCommandEvent & event);
+  void OnTemp(wxCommandEvent & event);
 };
 
 #endif
