@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program (in the file GPL.txt); if not, write to 
- * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -33,9 +32,9 @@
  * Define an array of indexes of the selected items.
  */
 #ifdef WX_DEFINE_ARRAY_LONG
-WX_DEFINE_ARRAY_LONG (long, IndexArray);
+WX_DEFINE_ARRAY_LONG(long, IndexArray);
 #else
-WX_DEFINE_ARRAY (long, IndexArray);
+WX_DEFINE_ARRAY(long, IndexArray);
 #endif
 
 // forward declarations
@@ -88,13 +87,13 @@ public:
   } FileListColumns;
 
 
-  FileListCtrl (wxWindow * parent, const wxWindowID id,
-                const wxPoint & pos, const wxSize & size);
+  FileListCtrl(wxWindow * parent, const wxWindowID id,
+               const wxPoint & pos, const wxSize & size);
 
-  virtual ~FileListCtrl ();
+  virtual ~FileListCtrl();
 
-  void ResetColumns ();
-  void DeleteAllItems ();
+  void ResetColumns();
+  void DeleteAllItems();
 
   /**
    * set visibility of a column
@@ -103,7 +102,7 @@ public:
    * @param visible
    */
   void
-  SetColumnVisible (const int col, const bool visible);
+  SetColumnVisible(const int col, const bool visible);
 
   /**
    * @param col column number
@@ -111,7 +110,7 @@ public:
    * @retval false invisible
    */
   bool
-  GetColumnVisible (const int col) const;
+  GetColumnVisible(const int col) const;
 
   /**
    * set column width
@@ -120,7 +119,7 @@ public:
    * @param width
    */
   void
-  SetColumnWidth (const int col, const int width);
+  SetColumnWidth(const int col, const int width);
 
   /**
    * get number of soring column
@@ -128,7 +127,7 @@ public:
    * @return number of column
    */
   int
-  GetSortColumn () const;
+  GetSortColumn() const;
 
   /**
    * set sorting column
@@ -136,7 +135,7 @@ public:
    * @param col column number
    */
   void
-  SetSortColumn (const int col);
+  SetSortColumn(const int col);
 
   /**
    * know whether to use full path in sorting
@@ -144,7 +143,7 @@ public:
    * @return true = use full path
    */
   bool
-  GetIncludePath () const;
+  GetIncludePath() const;
 
   /**
    * set whether to use full path in sorting
@@ -152,7 +151,7 @@ public:
    * @param value
    */
   void
-  SetIncludePath (bool value);
+  SetIncludePath(bool value);
 
   /**
    * know whether sorting is ascending or descending
@@ -160,7 +159,7 @@ public:
    * @return true = ascending
    */
   bool
-  GetSortAscending () const;
+  GetSortAscending() const;
 
   /**
    * set whether to sort ascending or descending
@@ -168,7 +167,7 @@ public:
    * @param ascending
    */
   void
-  SetSortAscending (bool ascending);
+  SetSortAscending(bool ascending);
 
   /**
    * get the "flat" setting
@@ -176,7 +175,7 @@ public:
    * @return true = flat
    */
   bool
-  IsFlat () const;
+  IsFlat() const;
 
   /**
    * change to either flat or single directory view
@@ -186,79 +185,76 @@ public:
    * @param flat
    */
   void
-  SetFlat (const bool flat);
+  SetFlat(const bool flat);
 
   /**
    * shall we contact the repository when updating,
    * so we get information about out-dated-ness?
    */
   bool
-  GetWithUpdate () const;
+  GetWithUpdate() const;
 
   void
-  SetWithUpdate (bool value);
+  SetWithUpdate(bool value);
 
   bool
-  GetShowUnversioned () const;
+  GetShowUnversioned() const;
 
   /**
    * shall we display unversioned file entries?
    */
   void
-  SetShowUnversioned (bool value);
+  SetShowUnversioned(bool value);
+
+  void
+  SetShowUnmodified(bool value);
+
+  void
+  SetShowModified(bool value);
+
+  void
+  SetShowConflicted(bool value);
 
   /**
    * shall external definitions be ignored/not updated?
    */
   bool
-  GetIgnoreExternals () const;
+  GetIgnoreExternals() const;
 
   void
-  SetIgnoreExternals (bool value);
+  SetIgnoreExternals(bool value);
 
   /**
    * shall we display ignored file entries?
    */
   bool
-  GetShowIgnored () const;
+  GetShowIgnored() const;
 
   void
-  SetShowIgnored (bool value);
+  SetShowIgnored(bool value);
 
-  void RefreshFileList ();
-  void RefreshFileList (const wxString & path);
+  void RefreshFileList();
+  void RefreshFileList(const wxString & path);
 
   const IndexArray
-  GetSelectedItems () const;
+  GetSelectedItems() const;
 
-//TODO  const svn::Targets
-//TODO  GetTargets () const;
-
-  /** 
+  /**
    * the selected @ref Status instances
    */
   const svn::StatusSel &
-  GetStatusSel () const;
-
-#if 0
-  /**
-   * determine the properties of what has been selected
-   * in terms of the relevant Action Flags.
-   */
-  unsigned int
-  GetSelectionActionFlags () const;
-#endif
+  GetStatusSel() const;
 
   svn::Context *
-  GetContext () const;
+  GetContext() const;
 
   void
-  SetContext (svn::Context * Context);
+  SetContext(svn::Context * Context);
 
   /**
    * Makes sure the columns are updated correctly
    */
-  void UpdateColumns ();
+  void UpdateColumns();
 
 private:
   /** private data for this class */
@@ -266,24 +262,25 @@ private:
   Data * m;
 
   // utility methods
-  void ShowMenu (wxPoint & pt);
-  void DeleteItem (long item);
+  void ShowMenu(wxPoint & pt);
+  void DeleteItem(long item);
 
-  void SetColumnImages ();
-  void ApplySortChanges ();
+  void SetColumnImages();
+  void ApplySortChanges();
 
   // message handlers
-  void OnKeyDown (wxKeyEvent & event);
-  void OnDoubleClick (wxListEvent & event);
-  void OnColumnLeftClick (wxListEvent & event);
-  void OnColumnEndDrag (wxListEvent & event);
-  void OnContextMenu (wxContextMenuEvent & event);
-  void OnBeginDrag (wxListEvent & event);
+  void OnKeyDown(wxKeyEvent & event);
+  void OnDoubleClick(wxListEvent & event);
+  void OnColumnLeftClick(wxListEvent & event);
+  void OnColumnEndDrag(wxListEvent & event);
+  void OnContextMenu(wxContextMenuEvent & event);
+  void OnBeginDrag(wxListEvent & event);
+  void OnSetFocus(wxFocusEvent & event);
 
-  void CreateLables (const svn::Status & status, const svn::Path & basePath);
+  void CreateLables(const svn::Status & status, const svn::Path & basePath);
 
 private:
-  DECLARE_EVENT_TABLE ()
+  DECLARE_EVENT_TABLE()
 };
 
 #endif
