@@ -22,6 +22,9 @@
  * ====================================================================
  */
 
+// stl
+#include <map>
+
 // wxWidgets
 #include "wx/wx.h"
 #include "wx/filename.h"
@@ -29,7 +32,6 @@
 #include "wx/imaglist.h"
 #include "wx/treectrl.h"
 #include "wx/confbase.h"
-#include "wx/hashmap.h"
 #include "wx/dnd.h"
 
 // svncpp
@@ -81,10 +83,10 @@ enum
 };
 
 static const unsigned int MAXLENGTH_BOOKMARK = 35;
-
-const static wxChar ConfigBookmarkFmt [] = wxT("/Bookmarks/Bookmark%ld");
-const static wxChar ConfigBookmarkCount [] = wxT("/Bookmarks/Count");
-const static wxChar ConfigFlatModeFmt [] = wxT("/Bookmarks/Bookmark%ldFlat");
+const static wxChar ConfigBookmarkFmt[] = wxT("/Bookmarks/Bookmark%ld");
+const static wxChar ConfigBookmarkCount[] = wxT("/Bookmarks/Count");
+const static wxChar ConfigFlatModeFmt[] = wxT("/Bookmarks/Bookmark%ldFlat");
+const static wxChar ConfigIndicateModifiedChildrenFmt[] = wxT("/Bookmarks/Bookmark%ldIndicateModifiedChildren");
 
 static const wxString EmptyString;
 
@@ -105,9 +107,11 @@ struct Bookmark
 public:
   svn::Context * context;
   bool flatMode;
+  bool indicateModifiedChildren;
 
-  Bookmark(bool flatMode_=false)
-      : context(0), flatMode(flatMode_)
+  Bookmark(bool flatMode_=false, bool indicateModifiedChildren_=false)
+    : context(0), flatMode(flatMode_), 
+      indicateModifiedChildren(indicateModifiedChildren_)
   {
   }
 
@@ -135,8 +139,7 @@ public:
 };
 
 static Bookmark InvalidBookmark;
-
-WX_DECLARE_STRING_HASH_MAP(Bookmark, BookmarkHashMap);
+typedef std::map<wxString, Bookmark>BookmarkHashMap;
 
 struct FolderBrowser::Data
 {
@@ -529,6 +532,10 @@ public:
     if (treeCtrl->IsExpanded(parentId))
       return;
 
+    wxFont fontBold (treeCtrl->GetFont());
+    fontBold.SetWeight(wxFONTWEIGHT_BOLD);
+    size_t parentLength = parentPath.Length() + 1; //+1 = path separator
+
     svn::Client client(GetContext());
     svn::Path parentPathUtf8(PathUtf8(parentPath));
 
@@ -541,6 +548,51 @@ public:
                     false);     // Use global ignores
 
     bool pathIsUrl = parentPathUtf8.isUrl();
+    bool indicateModifiedChildren  = GetSelectedBookmark().indicateModifiedChildren &&
+                                     !pathIsUrl;
+    std::map<wxString, int> modifiedEntriesMap;
+
+    if (indicateModifiedChildren)
+    {
+      // Only get interesting entries
+      svn::StatusEntries modifiedEntries = 
+        client.status(parentPathUtf8.c_str(), true, false);
+      wxChar pathSeparator = wxFileName::GetPathSeparator();
+
+      svn::StatusEntries::const_iterator it;
+      for (it = modifiedEntries.begin(); it != modifiedEntries.end(); it++)
+      {
+        const svn::Path modifiedPath((*it).path());
+        wxString path(PathToNative(modifiedPath).Mid(parentLength));
+        int separatorPos = path.Find(pathSeparator);
+
+        // we have to check, wether the entry we wanna add contains
+        // modified entries or is modified itself (in this case this
+        // counts) or if the modifications are deeper in the tree
+        // (in that case we only mark it as modified)
+        bool hasModifiedSubChildren = false;
+        if (wxNOT_FOUND != separatorPos)
+        {
+          wxString restPath(path.Mid(separatorPos+1));
+          path = path.Left(separatorPos);
+
+          if (wxNOT_FOUND != restPath.Find(pathSeparator))
+            hasModifiedSubChildren = true;
+        }
+
+        int modified_count = modifiedEntriesMap[path];
+        if (hasModifiedSubChildren)
+        {
+          if (0 == modified_count)
+            modifiedEntriesMap[path] = -1;
+        }
+        else if (modified_count < 0)
+          modifiedEntriesMap[path] = 1;
+        else
+          modifiedEntriesMap[path]++;
+      }
+    }
+    
 
     svn::StatusEntries::iterator it;
     for (it = entries.begin(); it != entries.end(); it++)
@@ -580,25 +632,36 @@ public:
           open_image = FOLDER_IMAGE_OPEN_FOLDER;
         }
 
+        wxString basename(Utf8ToLocal(filename.basename()));
+        FolderItemData * data = new FolderItemData(
+          FOLDER_TYPE_NORMAL, path,
+          basename,
+          TRUE);
+        data->setStatus(status);
 
         if ((status.textStatus() == svn_wc_status_modified) ||
-            (status.propStatus() == svn_wc_status_modified) ||
-            (HasModifiedChildren(status.path(), GetContext())))
+            (status.propStatus() == svn_wc_status_modified))
         {
           image = FOLDER_IMAGE_MODIFIED_FOLDER;
           open_image = FOLDER_IMAGE_MODIFIED_OPEN_FOLDER;
         }
 
-        FolderItemData * data = new FolderItemData(
-          FOLDER_TYPE_NORMAL, path,
-          Utf8ToLocal(filename.basename()),
-          TRUE);
-        data->setStatus(status);
+        int modified_count = 0;
+        if (indicateModifiedChildren)
+          modified_count = modifiedEntriesMap[path.Mid(parentLength)];
 
-        wxTreeItemId newId = treeCtrl->AppendItem(
-                               parentId,
-                               Utf8ToLocal(filename.basename()),
-                               image, image, data);
+        wxString label(basename);
+        if (modified_count > 0) 
+        {
+          label = wxString::Format(
+            wxT("%s (%u) "), basename.c_str(), modified_count);
+        }
+
+        wxTreeItemId newId = 
+          treeCtrl->AppendItem(parentId, label, image, image, data);
+
+        if (modified_count != 0)
+          treeCtrl->SetItemFont(newId, fontBold);
 
         bool hasSubDirs = true;
         if (!pathIsUrl)
@@ -883,7 +946,7 @@ public:
     }
   }
 
-  const bool
+  bool
   GetAuthPerBookmark() const
   {
     return singleContext == 0;
@@ -962,7 +1025,7 @@ FolderBrowser::RefreshFolderBrowser()
   SelectFolder(path);
 }
 
-const bool
+bool
 FolderBrowser::RemoveBookmark()
 {
   wxTreeItemId id = m->treeCtrl->GetSelection();
@@ -1052,7 +1115,7 @@ FolderBrowser::SetAuthPerBookmark(const bool value)
   m->SetAuthPerBookmark(value);
 }
 
-const bool
+bool
 FolderBrowser::GetAuthPerBookmark() const
 {
   return m->GetAuthPerBookmark();
@@ -1100,6 +1163,9 @@ FolderBrowser::WriteConfig(wxConfigBase * cfg) const
     else
       cfg->Write(keyFlatMode, (long)0);
 
+    cfg->Write(wxString::Format(ConfigIndicateModifiedChildrenFmt, item),
+               it->second.indicateModifiedChildren ? 1 : 0);
+
     item++;
   }
 }
@@ -1125,12 +1191,17 @@ FolderBrowser::ReadConfig(wxConfigBase * cfg)
     if (!prefs.resetFlatModeOnStart)
       cfg->Read(keyFlatMode, &flatMode, 0);
 
+    // we wanna see modified children per default
+    long indicateModifiedChildren=0;
+    cfg->Read(wxString::Format(ConfigIndicateModifiedChildrenFmt, item),
+              &indicateModifiedChildren, 1);
+
     if (path.Length() > 0)
-      m->bookmarks [path] = Bookmark(flatMode != 0);
+      m->bookmarks [path] = Bookmark(flatMode != 0, indicateModifiedChildren != 0);
   }
 }
 
-const bool
+bool
 FolderBrowser::IsFlat() const
 {
   Bookmark & bookmark = m->GetSelectedBookmark();
@@ -1153,7 +1224,30 @@ FolderBrowser::SetFlat(bool flatMode)
   return true;
 }
 
-const bool
+bool
+FolderBrowser::GetIndicateModifiedChildren() const
+{
+  Bookmark & bookmark = m->GetSelectedBookmark();
+
+  if (&bookmark == &InvalidBookmark)
+    return false;
+
+  return bookmark.indicateModifiedChildren;
+}
+
+bool
+FolderBrowser::SetIndicateModifiedChildren(bool newValue)
+{
+  Bookmark & bookmark = m->GetSelectedBookmark();
+
+  if (&bookmark == &InvalidBookmark)
+    return false;
+
+  bookmark.indicateModifiedChildren = newValue;
+  return true;
+}
+
+bool
 FolderBrowser::GetAuthCache() const
 {
   return m->useAuthCache;
