@@ -55,7 +55,7 @@ public:
   /**
    * remove the selected bookmark from bookmarks
    */
-  const bool
+  bool
   RemoveBookmark();
 
   /**
@@ -147,7 +147,7 @@ public:
    *
    * @retval true flat-mode is turned on
    */
-  const bool
+  bool
   IsFlat() const;
 
   /**
@@ -161,16 +161,36 @@ public:
   bool
   SetFlat(bool flatMode);
 
+  /** 
+   * checks whether indication of modified content is
+   * switched on (for the selected bookmark)
+   *
+   * @retval true modified content is indicarted
+   */
+  bool
+  GetIndicateModifiedChildren() const;
+
+  /**
+   * switch on/off indication of modified children for
+   * the selected bookmark
+   *
+   * @param show
+   * @retval true success
+   * @retval false not set, no bookmark selected
+   */
+  bool
+  SetIndicateModifiedChildren(bool show);
+
   /**
    * @return auth per bookmark setting
    */
-  const bool
+  bool
   GetAuthPerBookmark() const;
 
   /**
    * check if authentication credentials should be cached or not
    */
-  const bool
+  bool
   GetAuthCache() const;
 
   /**
