@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program (in the file GPL.txt); if not, write to 
- * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -34,49 +33,49 @@
 // app
 #include "resolve_action.hpp"
 
-ResolveAction::ResolveAction (wxWindow * parent)
-  : Action (parent, _("Resolve"))
+ResolveAction::ResolveAction(wxWindow * parent)
+    : Action(parent, _("Resolve"))
 {
 }
 
 bool
-ResolveAction::Prepare ()
+ResolveAction::Prepare()
 {
   // No dialog for Resolve.
-  return Action::Prepare ();
+  return Action::Prepare();
 }
 
 bool
-ResolveAction::Perform ()
+ResolveAction::Perform()
 {
-  const std::vector<svn::Path> v = GetTargets ();
-  std::vector<svn::Path>::const_iterator it;
+  const svn::PathVector v = GetTargets();
+  svn::PathVector::const_iterator it;
 
-  svn::Client client (GetContext ());
-  for (it = v.begin (); it != v.end (); it++)
+  svn::Client client(GetContext());
+  for (it = v.begin(); it != v.end(); it++)
   {
     const svn::Path & path = *it;
 
-    client.resolved (path.c_str (), false);
+    client.resolved(path.c_str(), false);
   }
 
   return true;
 }
 
 bool
-ResolveAction::CheckStatusSel (const svn::StatusSel & statusSel)
+ResolveAction::CheckStatusSel(const svn::StatusSel & statusSel)
 {
   // allow only local+versioned files
-  if (!statusSel.hasVersioned ())
+  if (!statusSel.hasVersioned())
     return false;
 
-  if (statusSel.hasUnversioned ())
+  if (statusSel.hasUnversioned())
     return false;
 
-  if (!statusSel.hasLocal ())
+  if (!statusSel.hasLocal())
     return false;
 
-  if (!statusSel.hasFiles ())
+  if (!statusSel.hasFiles())
     return false;
 
   return true;
