@@ -66,7 +66,7 @@ public:
     delete m;
   }
 
-  const apr_status_t
+  apr_status_t
   Exception::apr_err() const
   {
     return m->apr_err;
