@@ -22,9 +22,6 @@
  * ====================================================================
  */
 
-// stl
-#include "svncpp/vector_wrapper.hpp"
-
 // subversion api
 #include "svn_types.h"
 
@@ -47,7 +44,7 @@ namespace svn
   struct StatusSel::Data
   {
     Targets targets;
-    std::vector<Status> status;
+    StatusVector status;
 
     bool hasDirs;
     bool hasFiles;
@@ -76,7 +73,7 @@ namespace svn
       clear();
 
       // ... and set from source
-      std::vector <Status>::const_iterator it;
+      StatusVector::const_iterator it;
       for (it = src.status.begin(); it != src.status.end(); it++)
       {
         push_back(*it);
@@ -101,7 +98,7 @@ namespace svn
     push_back(const Status & status_)
     {
       // skip pseudo entries
-      if (!status_.isset())
+      if (!status_.isSet())
         return;
 
       if (!status_.isVersioned())
@@ -186,6 +183,12 @@ namespace svn
     return m->targets.array(pool);
   }
 
+  const StatusVector &
+  StatusSel::statusVector() const
+  {
+    return m->status;
+  }
+
   const Targets &
   StatusSel::targets() const
   {
@@ -217,7 +220,7 @@ namespace svn
     m->status.reserve(size);
   }
 
-  StatusSel::operator const std::vector<Path> & () const
+  StatusSel::operator const PathVector & () const
   {
     return m->targets;
   }
