@@ -1,22 +1,21 @@
-#/bin/bash
+#!/bin/bash
 #
 # ====================================================================
-# Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+# Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
 #
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
-# along with this program (in the file GPL.txt); if not, write to 
-# the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
-# Boston, MA  02110-1301  USA
+# along with this program (in the file GPL.txt.
+# If not, see <http://www.gnu.org/licenses/>.
 #
 # This software consists of voluntary contributions made by many
 # individuals.  For exact contribution history, see the revision
@@ -28,15 +27,13 @@
 # Usage example to beautify all of the cpp files in src:
 # >../tools/beautify.sh *.cpp
 
-INDENT="indent -nut --indent-level2 --braces-after-if-line --brace-indent0 --no-blank-lines-after-commas --declaration-indentation1"
-for FILE in $@ ; do 
+INDENT="astyle --options=.astylerc"
+for FILE in $@ ; do
   if test ! -f $FILE ; then
     echo "Invalid file $FILE" >&2
   else
-    mv $FILE $FILE.orig
     #now for the style
-    $INDENT $FILE.orig -o $FILE
-    rm $FILE.orig
+    $INDENT $FILE
   fi
 done
 
