@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 #
 # ====================================================================
-# Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+# Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
 #
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 # 
 # This program is distributed in the hope that it will be useful,
@@ -14,9 +14,8 @@
 # GNU General Public License for more details.
 # 
 # You should have received a copy of the GNU General Public License
-# along with this program (in the file GPL.txt); if not, write to 
-# the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
-# Boston, MA  02110-1301  USA
+# along with this program (in the file GPL.txt.  
+# If not, see <http://www.gnu.org/licenses/>.
 #
 # This software consists of voluntary contributions made by many
 # individuals.  For exact contribution history, see the revision
@@ -46,6 +45,7 @@ VERSION_HPP_FILE = "src/version.hpp"
 RAPIDSVN_ISS_FILE = "packages/win32/rapidsvn.iss"
 DEBIAN_FILES_FILE = "packages/debian/files"
 MAKE_OSX_BUNDLE_FILE = "packages/osx/make_osx_bundle.sh"
+SVNCPP_VERSION_HPP_FILE = "include/svncpp/version.hpp"
 
 class Version:
     def __init__(self, filename):
@@ -55,6 +55,7 @@ class Version:
         self.patch = ""
         self.str = ""
         self.milestone = ""
+        self.number = 0x000000
 
         self.readFromFile(filename)
         self.year = date.today().year
@@ -71,19 +72,34 @@ class Version:
         if len(self.patch) > 0:
           self.str += "-" + self.patch;
         self.milestone = version.attributes["milestone"].value
+        self.number = (int('0' + self.major, 10) << 24) + \
+            (int(self.minor, 10) << 16) + \
+            (int('0' + self.micro, 10) << 8) + \
+            int('0' + self.patch, 10)
 
 def replace(fname, regex, newval, what):
-    s = open(fname, "r").read()
-    s_old = s
+    s_old = open(fname, "r").read()
+    rest = s_old
     r = re.compile(regex)
-    m = r.search(s)
-    if not m:
+    m = r.search(rest)
+    found = False
+    s = ""
+    while m:
+        found = True
+        s += rest[:m.start()] + newval
+        rest = rest[m.end():]
+        m = r.search(rest)
+    
+    s += rest
+
+    if not found:
         print "%s: %s not found" % (fname, what)
+    elif s == s_old:
+        print "%s: %s already replaced" % (fname, what)
     else:
-        s = s[:m.start()] + newval + s[m.end():]
-        if (s != s_old):
-            open(fname, "w").write(s)
-            print "%s: %s changed" % (fname, what)
+        open(fname, "w").write(s)
+        print "%s: %s changed" % (fname, what)
+
 
 class VersionChecker:
     def __init__(self):
@@ -178,6 +194,11 @@ class VersionChecker:
                 "DISKIMAGE=RapidSVN-%s" % (self.version.str), \
                 "DISKIMAGE")
 
+    def checkSvncppVersionHpp(self):
+        replace(SVNCPP_VERSION_HPP_FILE, 'SVNCPP_VERSION .*', \
+            "SVNCPP_VERSION 0x%08x" % self.version.number, \
+            'SVNCPP_VERSION')
+
     def run(self):
         print "Version information:"
         print "  Major: ", self.version.major
@@ -185,6 +206,7 @@ class VersionChecker:
         print "  Micro: ", self.version.micro
         print "  Patch: ", self.version.patch
         print "  Str:   ", self.version.str
+        print "  Number: 0x%08x" % self.version.number
         print "  Milestone: ", self.version.milestone
 
         self.checkConfigureIn()
@@ -192,6 +214,7 @@ class VersionChecker:
         self.checkRapidsvnIss()
         self.checkDebianFiles()
         self.checkMakeOsXBundle()
+        self.checkSvncppVersionHpp()
 
 if __name__ == "__main__":
     vc = VersionChecker()
