@@ -66,15 +66,33 @@ def readCurrentRevision():
   m=re.search("Revision: ([0-9]+)",t)
   return m.group(1)
 
+def patchVersionHeader(revision):
+  # first undo any previous patch
+  VERSION_HEADER="src/version.hpp"
+  REVISION_DEFINE="#define RAPIDSVN_VER_REVISION "
+  run("svn", ["revert", VERSION_HEADER], 1)
+
+  # now read the header
+  original=open(VERSION_HEADER, "r").read()
+  m=re.search(REVISION_DEFINE + "[0-9]+", original)
+  if not m:
+    raise Exception("%s' nicht gefunden in '%s'" % (REVISION_DEFINE, VERSION_HEADER))
+
+  # patch the revision
+  patched=original[:m.start()] + REVISION_DEFINE + str(revision) + original[m.end():]
+  open(VERSION_HEADER, "w").write(patched)
+
 def buildApplicationVc6():
-  print "Rebuild rapidsvn (using msdev"
-  run('msdev', ['rapidsvn.dsw', '/MAKE',  'ALL',  '/REBUILD'])
+  print "Rebuild rapidsvn (using Visual C++ 6.0 msdev)"
+  out=open('msdev.log', 'w')
+  out.write(run('msdev', ['build\\vc6\\rapidsvn.dsw', '/MAKE',  'ALL',  '/REBUILD'], silent=True))
 
 
 def buildApplicationVc2005():
-  print "Rebuild rapidsvn (using msdev"
-  run('vcbuild', ['/useenv', '/rebuild', 'build\\vc2005\\rapidsvn.sln', 'Release|Win32'])
-  run('vcbuild', ['/useenv', '/rebuild', 'build\\vc2005\\rapidsvn.sln', 'Unicode Release|Win32'])
+  out=open('vcbuild.log', 'w')
+  print "Rebuild rapidsvn (using Visual C++ 2005 vcbuild)"
+  out.write(run('vcbuild', ['/useenv', '/rebuild', 'build\\vc2005\\rapidsvn.sln', 'Release|Win32'], silent=True))
+  out.write(run('vcbuild', ['/useenv', '/rebuild', 'build\\vc2005\\rapidsvn.sln', 'Unicode Release|Win32'], silent=True))
 
 
 def buildMessages():
@@ -94,7 +112,7 @@ def buildMessages():
       msgfmt.make(po,mo)
 
 
-def buildInstaller(compiler):
+def buildInstaller(compiler, suffix):
   print "Clean installer"
   os.chdir("packages/win32")
   # Remove files
@@ -104,13 +122,14 @@ def buildInstaller(compiler):
   for n in x: os.unlink(n)
 
   print "Fetching files for installer"
+  out=open('innosetup.log', 'w')
   if compiler=='vc2005':
-    run('cmd.exe', ['/c', 'FetchFiles_vs2005.bat'])
+    out.write(run('cmd.exe', ['/c', 'FetchFiles_vs2005.bat'], silent=True))
   else:
-    run('cmd.exe', ['/c', 'FetchFiles.bat'])
+    out.write(run('cmd.exe', ['/c', 'FetchFiles.bat'], silent=True))
   innosetup="%s\iscc.exe" % getEnviron("INNOSETUP")
   print "Build installer (using %s)" %innosetup
-  run(innosetup, ['rapidsvn.iss'])
+  out.write(run(innosetup, ['rapidsvn.iss'], silent=True))
 
   #Get the name of the package and rename it
   n=glob.glob("Output/RapidSVN*exe")
@@ -120,7 +139,7 @@ def buildInstaller(compiler):
   old=n[0]
   e=os.path.splitext(old)
   print e
-  pkg="%s-%s%s" % (e[0],currentRevision,e[1])
+  pkg="%s-%s%s%s" % (e[0],currentRevision,suffix,e[1])
   os.rename(old, pkg)
   print "The new package is: %s" % (pkg)
   os.chdir("../..")
@@ -141,7 +160,7 @@ def makeApplication():
     print "Hm, seems like we have a build error: aborting"
     sys.exit(1)
 
-def buildMacDiskImage():
+def buildMacDiskImage(suffix):
   print 'Build Mac Disk Image'
   os.chdir('packages/osx')
   run('./make_osx_bundle.sh', silent=True)
@@ -154,7 +173,7 @@ def buildMacDiskImage():
   old=n[0]
   e=os.path.splitext(old)
   print e
-  pkg="%s-%s%s" % (e[0],currentRevision,e[1])
+  pkg="%s-%s%s%s" % (e[0],currentRevision,suffix,e[1])
   os.rename(old, pkg)
   print "The new package is: %s" % (pkg)
   os.chdir("../..")
@@ -175,7 +194,7 @@ def uploadInstaller(pkg):
   run(scp,  [pkg, url])
 
 def usage():
-  print "Usage: create_nightly.py [--compiler={vc2005, vc6}]"
+  print "Usage: create_nightly.py [--compiler={vc2005, vc6}] [--suffix=<text>] [--force] [--skip-compile] [--skip-installer] [--skip-upload]"
   print
 
 if __name__ == '__main__':
@@ -186,8 +205,13 @@ if __name__ == '__main__':
 
   # Parse the options
   compiler=None
+  suffix=""
+  skipCompile=False
+  skipInstaller=False
+  skipUpload=False
+  force=False
   try:
-    opts, args=getopt(sys.argv[1:], [], ['compiler='])
+    opts, args=getopt(sys.argv[1:], [], ['compiler=', 'suffix=', 'skip-compile', 'skip-installer', 'skip-upload', 'force'])
 
     if len(args) > 1:
       raise Exception()
@@ -198,6 +222,16 @@ if __name__ == '__main__':
           raise Exception()
         else:
           compiler = value
+      elif opt == '--suffix':
+        suffix = value
+      elif opt == '--skip-compile':
+        skipCompile=True
+      elif opt == '--skip-installer':
+        skipInstaller=True
+      elif opt == '--skip-upload':
+        skipUpload=True
+      elif opt == '--force':
+        force=True
 
   except:
     usage()
@@ -218,9 +252,12 @@ if __name__ == '__main__':
   # Now decide whether or not we have to create a nightly build
   lastSuccessfulRevision=readLastSuccessfulRevision()
   currentRevision=readCurrentRevision()
+  patchVersionHeader(currentRevision)
 
   if "" == lastSuccessfulRevision:
     print "No successful previous build detected"
+  elif force:
+    print "Forcing the build"
   elif currentRevision <= lastSuccessfulRevision:
     print "No newer revision detected, aborting (last successful=%s, current=%s)" % (lastSuccessfulRevision, currentRevision)
     sys.exit(0)
@@ -229,15 +266,17 @@ if __name__ == '__main__':
 
   pkg = ''
   if system == 'Darwin':
-    makeApplication()
-    pkg=buildMacDiskImage()
+    if not skipCompile: makeApplication()
+    if not skipInstaller: pkg=buildMacDiskImage(suffix)
   elif system == 'Windows':
-    if compiler in [None, 'vc6']:
-      buildApplicationVc6()
-    elif compiler == 'vc2005':
-      buildApplicationVc2005()
-    pkg=buildInstaller(compiler)
-  uploadInstaller(pkg)
+    if not skipCompile:
+      if compiler in [None, 'vc6']:
+        buildApplicationVc6()
+      elif compiler == 'vc2005':
+        buildApplicationVc2005()
+    if not skipInstaller: pkg=buildInstaller(compiler, suffix)
+
+  if not skipUpload: uploadInstaller(pkg)
 
   #remember revision
   open(FILENAME, "w").write(currentRevision)
